import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'SF Mobile Food Vendors';
  
  const circleRadius = 5;

  const xValue = d => d.Latitude;
  const xAxisLabel = 'Latitude';
  
  const yValue = d => d.Longitude;
  const yAxisLabel = 'Longitude';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
	const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();

  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  	.ticks(5)
    .tickSize(-innerHeight)
    .tickPadding(20);
  
  const yAxis = axisLeft(yScale)
  	.ticks(5)
    .tickSize(-innerWidth)
    .tickPadding(20);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -93)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  g.selectAll('circle').data(data)
    .enter().append('circle')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius);
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};

csv('https://vizhub.com/alice-chau/datasets/Mobile_Food_Facility_Permit.csv')
  .then(data => {
    console.log(data);
    data = data.filter(d => d.Longitude != 0);
  	data.forEach(d => {
      d.Latitude = +d.Latitude;
      d.Longitude = +d.Longitude;
      if(d.Longitude === 0){
        console.log(d)
      }
  	});
  	render(data);
  })


/* csv('https://vizhub.com/curran/datasets/auto-mpg.csv')
  .then(data => {
    data.forEach(d => {
      d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.weight = +d.weight;
      d.acceleration = +d.acceleration;
      d.year = +d.year;  
    });
    
  });
  */